@@ -1,8 +1,63 @@
+#' Active Subnetwork Search + Enrichment Analysis Wrapper for a Single Iteration
+#'
+#' @param i current iteration index (default = \code{NULL})
+#' @param dirs vector of directories for parallel runs
+#' @inheritParams active_snw_search
+#' @inheritParams enrichment_analyses
+#' @inheritParams active_snw_enrichment_wrapper
+#'
+#' @return Data frame of enrichment results using active subnetwork search results
+single_iter_wrapper <- function(i = NULL, dirs, input_processed, pin_path, score_quan_thr, sig_gene_thr, search_method, silent_option, use_all_positives,
+                                geneInitProbs, saTemp0, saTemp1, saIter, gaPop, gaIter, gaThread, gaCrossover, gaMut,
+                                grMaxDepth, grSearchDepth, grOverlap, grSubNum, gset_list, adj_method, enrichment_threshold,
+                                list_active_snw_genes) {
+  snws_file <- "active_snws"
+  dir_for_parallel_run <- NULL
+  if (!is.null(i)) {
+    snws_file <- paste0("active_snws_", i)
+    dir_for_parallel_run <- dirs[i]
+  }
+  snws <- active_snw_search(
+    input_for_search = input_processed,
+    pin_name_path = pin_path,
+    snws_file = snws_file,
+    dir_for_parallel_run = dir_for_parallel_run,
+    score_quan_thr = score_quan_thr,
+    sig_gene_thr = sig_gene_thr,
+    search_method = search_method,
+    seedForRandom = ifelse(is.null(i), 1234, i),
+    silent_option = silent_option,
+    use_all_positives = use_all_positives,
+    geneInitProbs = ifelse(!is.null(i), geneInitProbs[i], geneInitProbs),
+    saTemp0 = saTemp0, saTemp1 = saTemp1, saIter = saIter,
+    gaPop = gaPop, gaIter = gaIter,
+    gaThread = gaThread,
+    gaCrossover = gaCrossover, gaMut = gaMut,
+    grMaxDepth = grMaxDepth, grSearchDepth = grSearchDepth,
+    grOverlap = grOverlap, grSubNum = grSubNum
+  )
+  enrichment_res <- enrichment_analyses(
+    snws = snws,
+    sig_genes_vec = input_processed$GENE,
+    pin_name_path = pin_path,
+    genes_by_term = gset_list$genes_by_term,
+    term_descriptions = gset_list$term_descriptions,
+    adj_method = adj_method,
+    enrichment_threshold = enrichment_threshold,
+    list_active_snw_genes = list_active_snw_genes
+  )
+  return(enrichment_res)
+}
+
+
+
 #' Wrapper for Active Subnetwork Search + Enrichment over Single/Multiple Iteration(s)
 #'
 #' @param input_processed processed input data frame
 #' @param pin_path path/to/PIN/file
 #' @param gset_list list for gene sets
+#' @param disable_parallel boolean to indicate whether to disable parallel runs
+#'  via \code{foreach} (default = FALSE)
 #' @inheritParams run_pathfindR
 #' @inheritParams active_snw_search
 #' @inheritParams enrichment_analyses
@@ -20,6 +75,7 @@ active_snw_enrichment_wrapper <- function(input_processed,
                                           list_active_snw_genes,
                                           adj_method = "bonferroni",
                                           search_method = "GR",
+                                          disable_parallel = FALSE,
                                           use_all_positives = FALSE,
                                           iterations = 10, n_processes = NULL,
                                           score_quan_thr = 0.8, sig_gene_thr = 0.02,
@@ -76,6 +132,10 @@ active_snw_enrichment_wrapper <- function(input_processed,
     stop("`silent_option` should be either TRUE or FALSE")
   }
 
+  if (!is.logical(disable_parallel)) {
+    stop("`disable_parallel` should be either TRUE or FALSE")
+  }
+
   if (!is.numeric(iterations)) {
     stop("`iterations` should be a positive integer")
   }
@@ -90,60 +150,38 @@ active_snw_enrichment_wrapper <- function(input_processed,
 
     for (i in base::seq_len(iterations)) {
       dir_i <- file.path("active_snw_searches", paste0("Iteration_", i))
-      dir.create(dir_i, recursive = TRUE)
+      dir.create(dir_i, recursive = TRUE, showWarnings = FALSE)
       dirs <- c(dirs, dir_i)
     }
   }
 
-  single_iter_wrapper <- function(i = NULL) {
-    snws_file <- "active_snws"
-    dir_for_parallel_run <- NULL
-    if (!is.null(i)) {
-      snws_file <- paste0("active_snws_", i)
-      dir_for_parallel_run <- dirs[i]
-    }
-    snws <- active_snw_search(
-      input_for_search = input_processed,
-      pin_name_path = pin_path,
-      snws_file = snws_file,
-      dir_for_parallel_run = dir_for_parallel_run,
-      score_quan_thr = score_quan_thr,
-      sig_gene_thr = sig_gene_thr,
-      search_method = search_method,
-      seedForRandom = ifelse(is.null(i), 1234, i),
-      silent_option = silent_option,
-      use_all_positives = use_all_positives,
-      geneInitProbs = ifelse(!is.null(i), geneInitProbs[i], geneInitProbs),
-      saTemp0 = saTemp0, saTemp1 = saTemp1, saIter = saIter,
-      gaPop = gaPop, gaIter = gaIter,
-      gaThread = gaThread,
-      gaCrossover = gaCrossover, gaMut = gaMut,
-      grMaxDepth = grMaxDepth, grSearchDepth = grSearchDepth,
-      grOverlap = grOverlap, grSubNum = grSubNum
-    )
-    enrichment_res <- enrichment_analyses(
-      snws = snws,
-      sig_genes_vec = input_processed$GENE,
-      pin_name_path = pin_path,
-      genes_by_term = gset_list$genes_by_term,
-      term_descriptions = gset_list$term_descriptions,
-      adj_method = adj_method,
-      enrichment_threshold = enrichment_threshold,
-      list_active_snw_genes = list_active_snw_genes
-    )
-    return(enrichment_res)
-  }
-
   if (iterations == 1) {
-    combined_res <- single_iter_wrapper()
+    combined_res <- single_iter_wrapper(i = NULL, dirs, input_processed, pin_path, score_quan_thr, sig_gene_thr, search_method, silent_option, use_all_positives,
+                                        geneInitProbs, saTemp0, saTemp1, saIter, gaPop, gaIter, gaThread, gaCrossover, gaMut,
+                                        grMaxDepth, grSearchDepth, grOverlap, grSubNum, gset_list, adj_method, enrichment_threshold,
+                                        list_active_snw_genes)
   } else {
-    cl <- parallel::makeCluster(n_processes, setup_strategy = "sequential")
-    doParallel::registerDoParallel(cl)
-    `%dopar%` <- foreach::`%dopar%`
-    combined_res <- foreach::foreach(i = 1:iterations, .combine = rbind) %dopar% {
-      single_iter_wrapper(i)
+    if (!disable_parallel) {
+      cl <- parallel::makeCluster(n_processes, setup_strategy = "sequential")
+      doParallel::registerDoParallel(cl)
+      `%dopar%` <- foreach::`%dopar%`
+      combined_res <- foreach::foreach(i = 1:iterations, .combine = rbind, .packages = "pathfindR") %dopar% {
+        single_iter_wrapper(i, dirs, input_processed, pin_path, score_quan_thr, sig_gene_thr, search_method, silent_option, use_all_positives,
+                            geneInitProbs, saTemp0, saTemp1, saIter, gaPop, gaIter, gaThread, gaCrossover, gaMut,
+                            grMaxDepth, grSearchDepth, grOverlap, grSubNum, gset_list, adj_method, enrichment_threshold,
+                            list_active_snw_genes)
+      }
+      parallel::stopCluster(cl)
+    } else {
+      combined_res <- c()
+      for (i in 1:iterations) {
+        current_res <- single_iter_wrapper(i, dirs, score_quan_thr, sig_gene_thr, search_method, silent_option, use_all_positives,
+                                           geneInitProbs, saTemp0, saTemp1, saIter, gaPop, gaIter, gaThread, gaCrossover, gaMut,
+                                           grMaxDepth, grSearchDepth, grOverlap, grSubNum, gset_list, adj_method, enrichment_threshold,
+                                           list_active_snw_genes)
+        combined_res <- rbind(combined_res, current_res)
+      }
     }
-    parallel::stopCluster(cl)
   }
   return(combined_res)
 }
@@ -328,7 +366,7 @@ input_processing <- function(input, p_val_threshold = 0.05,
   ## load and prep pin
   pin <- utils::read.delim(
     file = pin_path,
-    header = FALSE, stringsAsFactors = FALSE
+    header = FALSE
   )
 
   ## Genes not in pin
@@ -671,8 +709,7 @@ return_pin_path <- function(pin_name_path = "Biogrid") {
         function(i, nm, val) {
           data.frame(base::toupper(nm[[i]]),
             "pp",
-            base::toupper(val[[i]]),
-            stringsAsFactors = FALSE
+            base::toupper(val[[i]])
           )
         },
         val = adj_list, nm = names(adj_list)
@@ -691,7 +728,7 @@ return_pin_path <- function(pin_name_path = "Biogrid") {
     path <- normalizePath(pin_name_path)
     pin <- utils::read.delim(
       file = path, quote = "",
-      header = FALSE, stringsAsFactors = FALSE
+      header = FALSE
     )
     if (ncol(pin) != 3) {
       stop("The PIN file must have 3 columns and be tab-separated")
